Skip to contents

Given a path, this function converts the define xml to a DataDef/Metacore object.

Usage

define_to_metacore(path, quiet = deprecated(), verbose = "message")

Arguments

path

location of the define xml as a string

quiet

[Superseded] Option to quietly load in, this will suppress warnings, but not errors. Expects either TRUE or FALSE. Default behaviour is FALSE. As of v0.3.0 this argument is deprecated in favour of verbose.

verbose

A character string specifying the desired verbosity level. Must be one of:

"message"

(default) Messages and warnings are handled normally.

"warn"

Messages are suppressed, but warnings are allowed.

"collapse"

Warnings are collapsed into a single message indicating the number of suppressed warnings.

"silent"

Both messages and warnings are suppressed.

Value

Metacore/DataDef object